pub struct AuthorizationPolicyRecord {
pub policy_id: String,
pub version: u64,
pub owner: Option<AuthorizationPrincipal>,
pub grants: Vec<AuthorizationGrantRecord>,
pub revoked_grant_ids: Vec<String>,
pub separation_rules: Vec<AuthorizationSeparationRule>,
}Fields
policy_id: Stringversion: u64owner: Option<AuthorizationPrincipal>grants: Vec<AuthorizationGrantRecord>revoked_grant_ids: Vec<String>separation_rules: Vec<AuthorizationSeparationRule>Trait Implementations
Sourceimpl Clone for AuthorizationPolicyRecord
impl Clone for AuthorizationPolicyRecord
Sourcefn clone(&self) -> AuthorizationPolicyRecord
fn clone(&self) -> AuthorizationPolicyRecord
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for AuthorizationPolicyRecord
impl Debug for AuthorizationPolicyRecord
Sourceimpl Default for AuthorizationPolicyRecord
impl Default for AuthorizationPolicyRecord
Sourcefn default() -> AuthorizationPolicyRecord
fn default() -> AuthorizationPolicyRecord
Returns the “default value” for a type. Read more
Sourceimpl Message for AuthorizationPolicyRecord
impl Message for AuthorizationPolicyRecord
Sourcefn encoded_len(&self) -> usize
fn encoded_len(&self) -> usize
Returns the encoded length of the message without a length delimiter.
Sourcefn encode(&self, buf: &mut impl BufMut) -> Result<(), EncodeError>where
Self: Sized,
fn encode(&self, buf: &mut impl BufMut) -> Result<(), EncodeError>where
Self: Sized,
Encodes the message to a buffer. Read more
Sourcefn encode_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
fn encode_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
Encodes the message to a newly allocated buffer.
Sourcefn encode_length_delimited(
&self,
buf: &mut impl BufMut,
) -> Result<(), EncodeError>where
Self: Sized,
fn encode_length_delimited(
&self,
buf: &mut impl BufMut,
) -> Result<(), EncodeError>where
Self: Sized,
Encodes the message with a length-delimiter to a buffer. Read more
Sourcefn encode_length_delimited_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
fn encode_length_delimited_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
Encodes the message with a length-delimiter to a newly allocated buffer.
Sourcefn decode(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
fn decode(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
Decodes an instance of the message from a buffer. Read more
Sourcefn decode_length_delimited(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
fn decode_length_delimited(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
Decodes a length-delimited instance of the message from the buffer.
Sourcefn merge(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
fn merge(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
Decodes an instance of the message from a buffer, and merges it into
self. Read moreSourcefn merge_length_delimited(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
fn merge_length_delimited(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
Decodes a length-delimited instance of the message from buffer, and
merges it into
self.impl StructuralPartialEq for AuthorizationPolicyRecord