pub struct BudgetBalance {
pub limits: Option<BudgetLimits>,
pub reserved: Option<BudgetQuantities>,
pub observed: Option<BudgetQuantities>,
pub estimated: Option<BudgetQuantities>,
pub unconfirmed: Option<BudgetQuantities>,
pub overrun: Option<BudgetQuantities>,
pub available: Option<BudgetQuantities>,
}Fields
limits: Option<BudgetLimits>reserved: Option<BudgetQuantities>observed: Option<BudgetQuantities>estimated: Option<BudgetQuantities>unconfirmed: Option<BudgetQuantities>overrun: Option<BudgetQuantities>available: Option<BudgetQuantities>Trait Implementations
Sourceimpl Clone for BudgetBalance
impl Clone for BudgetBalance
Sourcefn clone(&self) -> BudgetBalance
fn clone(&self) -> BudgetBalance
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for BudgetBalance
impl Debug for BudgetBalance
Sourceimpl Default for BudgetBalance
impl Default for BudgetBalance
Sourcefn default() -> BudgetBalance
fn default() -> BudgetBalance
Returns the “default value” for a type. Read more
Sourceimpl Message for BudgetBalance
impl Message for BudgetBalance
Sourcefn encoded_len(&self) -> usize
fn encoded_len(&self) -> usize
Returns the encoded length of the message without a length delimiter.
Sourcefn encode(&self, buf: &mut impl BufMut) -> Result<(), EncodeError>where
Self: Sized,
fn encode(&self, buf: &mut impl BufMut) -> Result<(), EncodeError>where
Self: Sized,
Encodes the message to a buffer. Read more
Sourcefn encode_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
fn encode_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
Encodes the message to a newly allocated buffer.
Sourcefn encode_length_delimited(
&self,
buf: &mut impl BufMut,
) -> Result<(), EncodeError>where
Self: Sized,
fn encode_length_delimited(
&self,
buf: &mut impl BufMut,
) -> Result<(), EncodeError>where
Self: Sized,
Encodes the message with a length-delimiter to a buffer. Read more
Sourcefn encode_length_delimited_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
fn encode_length_delimited_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
Encodes the message with a length-delimiter to a newly allocated buffer.
Sourcefn decode(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
fn decode(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
Decodes an instance of the message from a buffer. Read more
Sourcefn decode_length_delimited(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
fn decode_length_delimited(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
Decodes a length-delimited instance of the message from the buffer.
Sourcefn merge(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
fn merge(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
Decodes an instance of the message from a buffer, and merges it into
self. Read moreSourcefn merge_length_delimited(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
fn merge_length_delimited(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
Decodes a length-delimited instance of the message from buffer, and
merges it into
self.Sourceimpl PartialEq for BudgetBalance
impl PartialEq for BudgetBalance
impl StructuralPartialEq for BudgetBalance