pub struct CeremonyAuthorizationEvidence {
pub decision_id: String,
pub request_id: String,
pub principal_id: String,
pub action: String,
pub scope: Option<AuthorizationScope>,
pub target_digest: String,
pub policy_version: u64,
pub admitted_at: String,
pub valid_until: String,
}Expand description
Sealed admission evidence. The referenced policy decision supplies the complete authenticated principal and any accepted-work/approval antecedent.
Fields
decision_id: Stringrequest_id: Stringprincipal_id: Stringaction: Stringscope: Option<AuthorizationScope>target_digest: Stringpolicy_version: u64admitted_at: StringCanonical RFC 3339, preserving the same precision as the sealed evidence.
valid_until: StringTrait Implementations
Sourceimpl Clone for CeremonyAuthorizationEvidence
impl Clone for CeremonyAuthorizationEvidence
Sourcefn clone(&self) -> CeremonyAuthorizationEvidence
fn clone(&self) -> CeremonyAuthorizationEvidence
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Default for CeremonyAuthorizationEvidence
impl Default for CeremonyAuthorizationEvidence
Sourcefn default() -> CeremonyAuthorizationEvidence
fn default() -> CeremonyAuthorizationEvidence
Returns the “default value” for a type. Read more
Sourceimpl Message for CeremonyAuthorizationEvidence
impl Message for CeremonyAuthorizationEvidence
Sourcefn encoded_len(&self) -> usize
fn encoded_len(&self) -> usize
Returns the encoded length of the message without a length delimiter.
Sourcefn encode(&self, buf: &mut impl BufMut) -> Result<(), EncodeError>where
Self: Sized,
fn encode(&self, buf: &mut impl BufMut) -> Result<(), EncodeError>where
Self: Sized,
Encodes the message to a buffer. Read more
Sourcefn encode_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
fn encode_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
Encodes the message to a newly allocated buffer.
Sourcefn encode_length_delimited(
&self,
buf: &mut impl BufMut,
) -> Result<(), EncodeError>where
Self: Sized,
fn encode_length_delimited(
&self,
buf: &mut impl BufMut,
) -> Result<(), EncodeError>where
Self: Sized,
Encodes the message with a length-delimiter to a buffer. Read more
Sourcefn encode_length_delimited_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
fn encode_length_delimited_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
Encodes the message with a length-delimiter to a newly allocated buffer.
Sourcefn decode(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
fn decode(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
Decodes an instance of the message from a buffer. Read more
Sourcefn decode_length_delimited(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
fn decode_length_delimited(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
Decodes a length-delimited instance of the message from the buffer.
Sourcefn merge(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
fn merge(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
Decodes an instance of the message from a buffer, and merges it into
self. Read moreSourcefn merge_length_delimited(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
fn merge_length_delimited(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
Decodes a length-delimited instance of the message from buffer, and
merges it into
self.impl StructuralPartialEq for CeremonyAuthorizationEvidence