pub struct CeremonyChildGroupState {
pub group_id: String,
pub step_id: String,
pub state_visit: u32,
pub state_iteration: u32,
pub step_iteration: u32,
pub active_claim_fence: String,
pub adopted_claim_fence: String,
pub children: Vec<PlannedCeremonyChildState>,
pub max_children: u32,
pub max_depth: u32,
pub completions: Vec<ChildCompletionState>,
}Fields
group_id: Stringstep_id: Stringstate_visit: u32state_iteration: u32step_iteration: u32active_claim_fence: Stringadopted_claim_fence: Stringchildren: Vec<PlannedCeremonyChildState>max_children: u32max_depth: u32completions: Vec<ChildCompletionState>Trait Implementations
Sourceimpl Clone for CeremonyChildGroupState
impl Clone for CeremonyChildGroupState
Sourcefn clone(&self) -> CeremonyChildGroupState
fn clone(&self) -> CeremonyChildGroupState
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for CeremonyChildGroupState
impl Debug for CeremonyChildGroupState
Sourceimpl Default for CeremonyChildGroupState
impl Default for CeremonyChildGroupState
Sourcefn default() -> CeremonyChildGroupState
fn default() -> CeremonyChildGroupState
Returns the “default value” for a type. Read more
Sourceimpl Message for CeremonyChildGroupState
impl Message for CeremonyChildGroupState
Sourcefn encoded_len(&self) -> usize
fn encoded_len(&self) -> usize
Returns the encoded length of the message without a length delimiter.
Sourcefn encode(&self, buf: &mut impl BufMut) -> Result<(), EncodeError>where
Self: Sized,
fn encode(&self, buf: &mut impl BufMut) -> Result<(), EncodeError>where
Self: Sized,
Encodes the message to a buffer. Read more
Sourcefn encode_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
fn encode_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
Encodes the message to a newly allocated buffer.
Sourcefn encode_length_delimited(
&self,
buf: &mut impl BufMut,
) -> Result<(), EncodeError>where
Self: Sized,
fn encode_length_delimited(
&self,
buf: &mut impl BufMut,
) -> Result<(), EncodeError>where
Self: Sized,
Encodes the message with a length-delimiter to a buffer. Read more
Sourcefn encode_length_delimited_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
fn encode_length_delimited_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
Encodes the message with a length-delimiter to a newly allocated buffer.
Sourcefn decode(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
fn decode(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
Decodes an instance of the message from a buffer. Read more
Sourcefn decode_length_delimited(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
fn decode_length_delimited(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
Decodes a length-delimited instance of the message from the buffer.
Sourcefn merge(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
fn merge(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
Decodes an instance of the message from a buffer, and merges it into
self. Read moreSourcefn merge_length_delimited(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
fn merge_length_delimited(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
Decodes a length-delimited instance of the message from buffer, and
merges it into
self.Sourceimpl PartialEq for CeremonyChildGroupState
impl PartialEq for CeremonyChildGroupState
impl StructuralPartialEq for CeremonyChildGroupState