pub struct CeremonyStepDeadlineState {
pub step_id: String,
pub state_visit: u32,
pub state_iteration: u32,
pub step_iteration: u32,
pub attempt: u32,
pub claim_fence: String,
pub deadline_at: String,
pub finished_by_role_id: String,
}Fields
step_id: Stringstate_visit: u32state_iteration: u32step_iteration: u32attempt: u32claim_fence: Stringdeadline_at: Stringfinished_by_role_id: StringTrait Implementations
Sourceimpl Clone for CeremonyStepDeadlineState
impl Clone for CeremonyStepDeadlineState
Sourcefn clone(&self) -> CeremonyStepDeadlineState
fn clone(&self) -> CeremonyStepDeadlineState
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for CeremonyStepDeadlineState
impl Debug for CeremonyStepDeadlineState
Sourceimpl Default for CeremonyStepDeadlineState
impl Default for CeremonyStepDeadlineState
Sourcefn default() -> CeremonyStepDeadlineState
fn default() -> CeremonyStepDeadlineState
Returns the “default value” for a type. Read more
Sourceimpl Message for CeremonyStepDeadlineState
impl Message for CeremonyStepDeadlineState
Sourcefn encoded_len(&self) -> usize
fn encoded_len(&self) -> usize
Returns the encoded length of the message without a length delimiter.
Sourcefn encode(&self, buf: &mut impl BufMut) -> Result<(), EncodeError>where
Self: Sized,
fn encode(&self, buf: &mut impl BufMut) -> Result<(), EncodeError>where
Self: Sized,
Encodes the message to a buffer. Read more
Sourcefn encode_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
fn encode_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
Encodes the message to a newly allocated buffer.
Sourcefn encode_length_delimited(
&self,
buf: &mut impl BufMut,
) -> Result<(), EncodeError>where
Self: Sized,
fn encode_length_delimited(
&self,
buf: &mut impl BufMut,
) -> Result<(), EncodeError>where
Self: Sized,
Encodes the message with a length-delimiter to a buffer. Read more
Sourcefn encode_length_delimited_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
fn encode_length_delimited_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
Encodes the message with a length-delimiter to a newly allocated buffer.
Sourcefn decode(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
fn decode(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
Decodes an instance of the message from a buffer. Read more
Sourcefn decode_length_delimited(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
fn decode_length_delimited(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
Decodes a length-delimited instance of the message from the buffer.
Sourcefn merge(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
fn merge(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
Decodes an instance of the message from a buffer, and merges it into
self. Read moreSourcefn merge_length_delimited(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
fn merge_length_delimited(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
Decodes a length-delimited instance of the message from buffer, and
merges it into
self.impl StructuralPartialEq for CeremonyStepDeadlineState