pub struct CeremonyTranscriptEntry {
pub step_id: String,
pub role_id: String,
pub output: Option<Struct>,
pub state_iteration: u32,
pub state_visit: u32,
}Expand description
One thing a seat contributed while running a step.
Fields
step_id: Stringrole_id: Stringoutput: Option<Struct>Structured output, as the step produced it. Empty when it produced none.
state_iteration: u32state_visit: u32Trait Implementations
Sourceimpl Clone for CeremonyTranscriptEntry
impl Clone for CeremonyTranscriptEntry
Sourcefn clone(&self) -> CeremonyTranscriptEntry
fn clone(&self) -> CeremonyTranscriptEntry
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for CeremonyTranscriptEntry
impl Debug for CeremonyTranscriptEntry
Sourceimpl Default for CeremonyTranscriptEntry
impl Default for CeremonyTranscriptEntry
Sourcefn default() -> CeremonyTranscriptEntry
fn default() -> CeremonyTranscriptEntry
Returns the “default value” for a type. Read more
Sourceimpl Message for CeremonyTranscriptEntry
impl Message for CeremonyTranscriptEntry
Sourcefn encoded_len(&self) -> usize
fn encoded_len(&self) -> usize
Returns the encoded length of the message without a length delimiter.
Sourcefn encode(&self, buf: &mut impl BufMut) -> Result<(), EncodeError>where
Self: Sized,
fn encode(&self, buf: &mut impl BufMut) -> Result<(), EncodeError>where
Self: Sized,
Encodes the message to a buffer. Read more
Sourcefn encode_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
fn encode_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
Encodes the message to a newly allocated buffer.
Sourcefn encode_length_delimited(
&self,
buf: &mut impl BufMut,
) -> Result<(), EncodeError>where
Self: Sized,
fn encode_length_delimited(
&self,
buf: &mut impl BufMut,
) -> Result<(), EncodeError>where
Self: Sized,
Encodes the message with a length-delimiter to a buffer. Read more
Sourcefn encode_length_delimited_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
fn encode_length_delimited_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
Encodes the message with a length-delimiter to a newly allocated buffer.
Sourcefn decode(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
fn decode(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
Decodes an instance of the message from a buffer. Read more
Sourcefn decode_length_delimited(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
fn decode_length_delimited(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
Decodes a length-delimited instance of the message from the buffer.
Sourcefn merge(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
fn merge(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
Decodes an instance of the message from a buffer, and merges it into
self. Read moreSourcefn merge_length_delimited(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
fn merge_length_delimited(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
Decodes a length-delimited instance of the message from buffer, and
merges it into
self.Sourceimpl PartialEq for CeremonyTranscriptEntry
impl PartialEq for CeremonyTranscriptEntry
impl StructuralPartialEq for CeremonyTranscriptEntry