pub struct DeliberationUpdate {
pub task_id: String,
pub phase: i32,
pub emitted_at: Option<Timestamp>,
pub payload: Option<Payload>,
}Expand description
Incremental update emitted during streaming deliberation.
Fields
task_id: Stringphase: i32emitted_at: Option<Timestamp>payload: Option<Payload>Implementations
Sourceimpl DeliberationUpdate
impl DeliberationUpdate
Sourcepub fn phase(&self) -> DeliberationPhase
pub fn phase(&self) -> DeliberationPhase
Returns the enum value of phase, or the default if the field is set to an invalid enum value.
Sourcepub fn set_phase(&mut self, value: DeliberationPhase)
pub fn set_phase(&mut self, value: DeliberationPhase)
Sets phase to the provided enum value.