pub struct ExternalContextBundle {
pub bundle_id: String,
pub schema_version: String,
pub summary: Option<ContextSummary>,
pub items: Vec<ContextItem>,
pub references: Vec<ContextReference>,
pub metadata: Option<Struct>,
}Expand description
Bounded, caller-materialized context bundle passed into a council.
The contract is intentionally generic: callers define item.kind
labels and attach machine-readable detail through attributes.
Fields
bundle_id: Stringschema_version: Stringsummary: Option<ContextSummary>items: Vec<ContextItem>references: Vec<ContextReference>metadata: Option<Struct>Trait Implementations
Sourceimpl Clone for ExternalContextBundle
impl Clone for ExternalContextBundle
Sourcefn clone(&self) -> ExternalContextBundle
fn clone(&self) -> ExternalContextBundle
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for ExternalContextBundle
impl Debug for ExternalContextBundle
Sourceimpl Default for ExternalContextBundle
impl Default for ExternalContextBundle
Sourcefn default() -> ExternalContextBundle
fn default() -> ExternalContextBundle
Returns the “default value” for a type. Read more
Sourceimpl Message for ExternalContextBundle
impl Message for ExternalContextBundle
Sourcefn encoded_len(&self) -> usize
fn encoded_len(&self) -> usize
Returns the encoded length of the message without a length delimiter.
Sourcefn encode(&self, buf: &mut impl BufMut) -> Result<(), EncodeError>where
Self: Sized,
fn encode(&self, buf: &mut impl BufMut) -> Result<(), EncodeError>where
Self: Sized,
Encodes the message to a buffer. Read more
Sourcefn encode_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
fn encode_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
Encodes the message to a newly allocated buffer.
Sourcefn encode_length_delimited(
&self,
buf: &mut impl BufMut,
) -> Result<(), EncodeError>where
Self: Sized,
fn encode_length_delimited(
&self,
buf: &mut impl BufMut,
) -> Result<(), EncodeError>where
Self: Sized,
Encodes the message with a length-delimiter to a buffer. Read more
Sourcefn encode_length_delimited_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
fn encode_length_delimited_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
Encodes the message with a length-delimiter to a newly allocated buffer.
Sourcefn decode(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
fn decode(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
Decodes an instance of the message from a buffer. Read more
Sourcefn decode_length_delimited(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
fn decode_length_delimited(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
Decodes a length-delimited instance of the message from the buffer.
Sourcefn merge(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
fn merge(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
Decodes an instance of the message from a buffer, and merges it into
self. Read moreSourcefn merge_length_delimited(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
fn merge_length_delimited(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
Decodes a length-delimited instance of the message from buffer, and
merges it into
self.Sourceimpl PartialEq for ExternalContextBundle
impl PartialEq for ExternalContextBundle
impl StructuralPartialEq for ExternalContextBundle