pub struct StreamCeremonyEnd {
pub resume_after_sequence: u64,
pub head_sequence: u64,
pub reason: i32,
}Fields
resume_after_sequence: u64Send this value back as after_sequence to resume without duplicates.
head_sequence: u64reason: i32Implementations
Sourceimpl StreamCeremonyEnd
impl StreamCeremonyEnd
Sourcepub fn reason(&self) -> StreamCeremonyEndReason
pub fn reason(&self) -> StreamCeremonyEndReason
Returns the enum value of reason, or the default if the field is set to an invalid enum value.
Sourcepub fn set_reason(&mut self, value: StreamCeremonyEndReason)
pub fn set_reason(&mut self, value: StreamCeremonyEndReason)
Sets reason to the provided enum value.