pub struct TaskMetadata {
pub source_event_id: String,
pub causation_id: String,
pub correlation_id: String,
pub council_contract_id: String,
pub output_contract_id: String,
pub execution_profile: Option<Struct>,
}Expand description
Integration-neutral task metadata. Product/domain identifiers belong in Task.attributes or ExternalContextBundle.metadata; the MADE only interprets causal ids and its own contract / execution hints.
Fields
source_event_id: Stringcausation_id: Stringcorrelation_id: Stringcouncil_contract_id: Stringoutput_contract_id: Stringexecution_profile: Option<Struct>Trait Implementations
Sourceimpl Clone for TaskMetadata
impl Clone for TaskMetadata
Sourcefn clone(&self) -> TaskMetadata
fn clone(&self) -> TaskMetadata
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for TaskMetadata
impl Debug for TaskMetadata
Sourceimpl Default for TaskMetadata
impl Default for TaskMetadata
Sourcefn default() -> TaskMetadata
fn default() -> TaskMetadata
Returns the “default value” for a type. Read more
Sourceimpl Message for TaskMetadata
impl Message for TaskMetadata
Sourcefn encoded_len(&self) -> usize
fn encoded_len(&self) -> usize
Returns the encoded length of the message without a length delimiter.
Sourcefn encode(&self, buf: &mut impl BufMut) -> Result<(), EncodeError>where
Self: Sized,
fn encode(&self, buf: &mut impl BufMut) -> Result<(), EncodeError>where
Self: Sized,
Encodes the message to a buffer. Read more
Sourcefn encode_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
fn encode_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
Encodes the message to a newly allocated buffer.
Sourcefn encode_length_delimited(
&self,
buf: &mut impl BufMut,
) -> Result<(), EncodeError>where
Self: Sized,
fn encode_length_delimited(
&self,
buf: &mut impl BufMut,
) -> Result<(), EncodeError>where
Self: Sized,
Encodes the message with a length-delimiter to a buffer. Read more
Sourcefn encode_length_delimited_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
fn encode_length_delimited_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
Encodes the message with a length-delimiter to a newly allocated buffer.
Sourcefn decode(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
fn decode(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
Decodes an instance of the message from a buffer. Read more
Sourcefn decode_length_delimited(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
fn decode_length_delimited(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
Decodes a length-delimited instance of the message from the buffer.
Sourcefn merge(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
fn merge(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
Decodes an instance of the message from a buffer, and merges it into
self. Read moreSourcefn merge_length_delimited(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
fn merge_length_delimited(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
Decodes a length-delimited instance of the message from buffer, and
merges it into
self.Sourceimpl PartialEq for TaskMetadata
impl PartialEq for TaskMetadata
impl StructuralPartialEq for TaskMetadata