pub struct TriggerEvent {
pub event_id: String,
pub kind: String,
pub source: String,
pub emitted_at: Option<Timestamp>,
pub requested_specialties: Vec<String>,
pub task_description_template: String,
pub constraints: Option<Constraints>,
pub payload: Option<Struct>,
pub external_context: Option<ExternalContextBundle>,
pub correlation_id: String,
pub causation_id: String,
}Expand description
Opaque event instructing MADE to run deliberations. The event carries its own domain payload and the list of specialties whose councils should be dispatched.
Fields
event_id: Stringkind: Stringfree-form, e.g. “alert.fired”, “case.opened”
source: Stringproducer identifier
emitted_at: Option<Timestamp>requested_specialties: Vec<String>task_description_template: Stringoptional literal task description supplied by the producer
constraints: Option<Constraints>payload: Option<Struct>opaque domain data
external_context: Option<ExternalContextBundle>correlation_id: Stringcausation_id: StringTrait Implementations
Sourceimpl Clone for TriggerEvent
impl Clone for TriggerEvent
Sourcefn clone(&self) -> TriggerEvent
fn clone(&self) -> TriggerEvent
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for TriggerEvent
impl Debug for TriggerEvent
Sourceimpl Default for TriggerEvent
impl Default for TriggerEvent
Sourcefn default() -> TriggerEvent
fn default() -> TriggerEvent
Returns the “default value” for a type. Read more
Sourceimpl Message for TriggerEvent
impl Message for TriggerEvent
Sourcefn encoded_len(&self) -> usize
fn encoded_len(&self) -> usize
Returns the encoded length of the message without a length delimiter.
Sourcefn encode(&self, buf: &mut impl BufMut) -> Result<(), EncodeError>where
Self: Sized,
fn encode(&self, buf: &mut impl BufMut) -> Result<(), EncodeError>where
Self: Sized,
Encodes the message to a buffer. Read more
Sourcefn encode_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
fn encode_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
Encodes the message to a newly allocated buffer.
Sourcefn encode_length_delimited(
&self,
buf: &mut impl BufMut,
) -> Result<(), EncodeError>where
Self: Sized,
fn encode_length_delimited(
&self,
buf: &mut impl BufMut,
) -> Result<(), EncodeError>where
Self: Sized,
Encodes the message with a length-delimiter to a buffer. Read more
Sourcefn encode_length_delimited_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
fn encode_length_delimited_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
Encodes the message with a length-delimiter to a newly allocated buffer.
Sourcefn decode(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
fn decode(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
Decodes an instance of the message from a buffer. Read more
Sourcefn decode_length_delimited(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
fn decode_length_delimited(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
Decodes a length-delimited instance of the message from the buffer.
Sourcefn merge(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
fn merge(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
Decodes an instance of the message from a buffer, and merges it into
self. Read moreSourcefn merge_length_delimited(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
fn merge_length_delimited(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
Decodes a length-delimited instance of the message from buffer, and
merges it into
self.Sourceimpl PartialEq for TriggerEvent
impl PartialEq for TriggerEvent
impl StructuralPartialEq for TriggerEvent